#!/bin/bash
##*************************************************************************##
##  CUBE        http://www.scalasca.org/                                   ##
##*************************************************************************##
##  Copyright (c) 2023                                                     ##
##  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          ##
##                                                                         ##
##  This software may be modified and distributed under the terms of       ##
##  a BSD-style license.  See the COPYING file in the package base         ##
##  directory for details.                                                 ##
##*************************************************************************##


dir=$(dirname "$0")

# default values
PACKAGEMAJOR=0
PACKAGEMINOR=0
PACKAGEBUGFIX=0
CUBEGUI_VERSION="branch"
branch_name="branch"

# ======  get version info from git repo or from tarball =============
if [ -d "../.git" ]; then #==== git controlled
    REVISION=`git rev-parse --short HEAD 2> /dev/null`d
    tag=`git describe 2> /dev/null`
    name=`git describe --all`
    name="${name//tags\//}" # remove tags/ from branch name
    branch_name="${name//heads\//}"
    branch_name="branch-$branch_name"
    #latest_tag=`git rev-list --tags --max-count=1`
    #latest_tag_name=`git describe --tags $latest_tag` # tag on which the branch is based on
else #==== tarball
    REVISION=`cat ../build-config/REVISION`
    library_current=$(grep 'library.current=' ../build-config/VERSION | cut -d'=' -f2)
    if [ "$library_current" -ne "0" ]; then # release-tarball
        PACKAGEMAJOR=$(grep 'package.major=' ../build-config/VERSION | cut -d'=' -f2)
        PACKAGEMINOR=$(grep 'package.minor=' ../build-config/VERSION | cut -d'=' -f2)
        PACKAGEBUGFIX=$(grep 'package.bugfix=' ../build-config/VERSION | cut -d'=' -f2)
        PACKAGESUFFIX=$(grep 'package.suffix=' ../build-config/VERSION | cut -d'=' -f2)
        CUBEGUI_VERSION="$PACKAGEMAJOR.$PACKAGEMINOR.$PACKAGEBUGFIX"
        tagged=1
    fi
fi

# if version is not a release: CUBEGUI_FULL-NAME should contain branch name instead
if [ -z "$tagged" ]; then
    FULL_NAME="CUBEGUI_SHORT_NAME \"-$branch_name\""
else
    FULL_NAME="CUBEGUI_SHORT_NAME \"-\" CUBEGUI_FULL_VERSION CUBEGUI_SUFFIX"
fi

QT_PATH=`type qmake`
QT_VERSION_CUBE=`qmake -v | grep -oP 'Using Qt version \K\d+\.\d+\.\d+' `

# ====== generate header which is otherwise generated by autoconf =============

cp $dir/cubegui-config.h.in $dir/cubegui-config.h
echo "
#define CUBEGUI_REVISION_  $REVISION
#define CUBEGUI_MAJOR_     $PACKAGEMAJOR
#define CUBEGUI_MINOR_     $PACKAGEMINOR
#define CUBEGUI_BUGFIX_    $PACKAGEBUGFIX
#define CUBEGUI_SUFFIX     $PACKAGESUFFIX
#define CUBEGUI_VERSION    \"$CUBEGUI_VERSION\"
#define CUBEGUI_SHORT_NAME \"CubeGUI\"
#define CUBEGUI_FULL_NAME  $FULL_NAME
#define PACKAGE_BUGREPORT  \"scalasca@fz-juelich.de\"
#define PACKAGE_URL        \"http://www.scalasca.org\"
#define QT_PATH            \"$QT_PATH\"
#define QT_VERSION_CUBE    \"$QT_VERSION_CUBE\"
#define PKGDATADIR         \"$PKGDATADIR\"

//==================================================================================

#define CUBE_CONCURRENT_LIB

// replace with #define WITH_WEB_ENGINE to show html documentation in improved widget (Requires openGL)
#undef WITH_WEB_ENGINE

#endif
" >> $dir/cubegui-config.h

INC='#include "cubegui-config.h"'
echo $INC > $dir/config.h
echo $INC > $dir/config-frontend.h
echo $INC > $dir/cubegui-version.h
echo $INC > $dir/cubegui-concurrent.h
